@@ -9,12 +9,11 @@
 import logging
 from dataclasses import dataclass
 from typing import ClassVar, TypeAlias
+
 import jwt
-from jwt import DecodeError, ExpiredSignatureError
-
-from init_helpers.dict_to_dataclass import dict_to_dataclass
-
 from auth_server_connector.auth_server_connector import AuthServerConnector, JWTPayload, TokenType
+from init_helpers.dict_to_dataclass import dict_to_dataclass
+from jwt import DecodeError, ExpiredSignatureError
 
 logger = logging.getLogger(__name__)
 
@@ -28,7 +27,7 @@ class ExpiredTokenError(Exception):
 
 
 class TokenValidator:
-    _SIGNATURE_ALGORITHM: ClassVar[str] = "RS256"
+    _SIGNATURE_ALGORITHM: ClassVar[str] = "ES256"
 
     @dataclass
     class Context:
